<?php
/* Copyright (C) 2001-2005 Rodolphe Quiedeville <rodolphe@quiedeville.org>
 * Copyright (C) 2004-2015 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2005-2012 Regis Houssin        <regis.houssin@inodbox.com>
 * Copyright (C) 2015      Jean-François Ferry	<jfefe@aternatik.fr>
 * Copyright (C) 2023      Arnaud Avaullée	<arnaud@pragma-tech.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

/**
 *	\file       clientpart/clientpartindex.php
 *	\ingroup    clientpart
 *	\brief      Home page of clientpart top menu
 */

// Load Dolibarr environment
$res = 0;
// Try main.inc.php into web root known defined into CONTEXT_DOCUMENT_ROOT (not always defined)
if (!$res && !empty($_SERVER["CONTEXT_DOCUMENT_ROOT"])) {
	$res = @include $_SERVER["CONTEXT_DOCUMENT_ROOT"]."/main.inc.php";
}
// Try main.inc.php into web root detected using web root calculated from SCRIPT_FILENAME
$tmp = empty($_SERVER['SCRIPT_FILENAME']) ? '' : $_SERVER['SCRIPT_FILENAME']; $tmp2 = realpath(__FILE__); $i = strlen($tmp) - 1; $j = strlen($tmp2) - 1;
while ($i > 0 && $j > 0 && isset($tmp[$i]) && isset($tmp2[$j]) && $tmp[$i] == $tmp2[$j]) {
	$i--; $j--;
}
if (!$res && $i > 0 && file_exists(substr($tmp, 0, ($i + 1))."/main.inc.php")) {
	$res = @include substr($tmp, 0, ($i + 1))."/main.inc.php";
}
if (!$res && $i > 0 && file_exists(dirname(substr($tmp, 0, ($i + 1)))."/main.inc.php")) {
	$res = @include dirname(substr($tmp, 0, ($i + 1)))."/main.inc.php";
}
// Try main.inc.php using relative path
if (!$res && file_exists("../main.inc.php")) {
	$res = @include "../main.inc.php";
}
if (!$res && file_exists("../../main.inc.php")) {
	$res = @include "../../main.inc.php";
}
if (!$res && file_exists("../../../main.inc.php")) {
	$res = @include "../../../main.inc.php";
}
if (!$res) {
	die("Include of main fails");
}

//REQUIRES
require_once DOL_DOCUMENT_ROOT.'/core/class/html.formfile.class.php';
// CONTACTREQUIRE
require_once DOL_DOCUMENT_ROOT.'/contact/class/contact.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/contact.lib.php';

require_once DOL_DOCUMENT_ROOT.'/core/lib/files.lib.php';

require_once DOL_DOCUMENT_ROOT.'/core/class/html.formcompany.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/html.formadmin.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/doleditor.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/extrafields.class.php';

// CATEGORIEREQUIRE
require_once DOL_DOCUMENT_ROOT.'/categories/class/categorie.class.php';

// Load translation files required by the page
$langs->loadLangs(array("clientpart@clientpart"));

$action		= (GETPOST('action', 'aZ09') ? GETPOST('action', 'aZ09') : 'view');
$cancel		= GETPOST('cancel', 'alpha');
$backtopage = GETPOST('backtopage', 'alpha');
$backtopageforcancel = GETPOST('backtopageforcancel', 'alpha');
$backtopagejsfields = GETPOST('backtopagejsfields', 'alpha');
$dol_openinpopup = GETPOST('dol_openinpopup', 'aZ09');
$confirm	= GETPOST('confirm', 'alpha');

$socid = GETPOST('socid', 'int') ?GETPOST('socid', 'int') : GETPOST('id', 'int');

if (empty($socid) && $action == 'view') {
	$action = 'create';
}
$id = $socid;


// DECLARATION OBJECT
$object = new Societe($db);
$extrafields = new ExtraFields($db);

// Security check
// if (! $user->rights->clientpart->myobject->read) {
// 	accessforbidden();
// }

if (isset($user->socid) && $user->socid > 0) {
	$action = '';
	$socid = $user->socid;
}

if ($socid > 0) {
	$object->fetch($socid);
}

$max = 5;
$now = dol_now();

$error = 0; $errors = array();
/*
 * Actions
 */

$canvas = $object->canvas ? $object->canvas : GETPOST("canvas");
$objcanvas = null;
if (!empty($canvas)) {
	require_once DOL_DOCUMENT_ROOT.'/core/class/canvas.class.php';
	$objcanvas = new Canvas($db, $action);
	$objcanvas->getCanvas('thirdparty', 'card', $canvas);
}

//permissions

$permissiontoread = $user->rights->particulier->read;
$permissiontoadd = $user->rights->particulier->whrite; // Used by the include of actions_addupdatedelete.inc.php and actions_lineupdown.inc.php
$permissiontodelete = $user->rights->particulier->delete;

/*$permissionnote = $user->rights->societe->creer; // Used by the include of actions_setnotes.inc.php
$permissiondellink = $user->rights->societe->creer; // Used by the include of actions_dellink.inc.php
$upload_dir = $conf->societe->multidir_output[isset($object->entity) ? $object->entity : 1];*/

if ($cancel) {
	if (!empty($backtopageforcancel)) {
		header("Location: " . $backtopageforcancel);
		exit;
	} elseif (!empty($backtopage)) {
		header("Location: " . $backtopage);
		exit;
	} else {
		header("Location: " . DOL_URL_ROOT . '/societe/list.php?sortfield=s.nom&sortorder=ASC&contextpage=thirdpartylist&limit=20&search_categ_cus=-1&search_categ_sup=-1&search_sale=-1&search_type_thirdparty=8&search_type=-1&search_options_clientpart_civilite=0&search_status=1&idmenu=183&mainmenu=companies&leftmenu=');
		exit;
	}
	$action = '';
}

// Add new or update third party
if ((!GETPOST('getcustomercode') && !GETPOST('getsuppliercode'))
	&& ($action == 'add' || $action == 'update') && $user->rights->societe->creer) {
	require_once DOL_DOCUMENT_ROOT.'/core/lib/functions2.lib.php';

	// PRAGMA Verif des champs obligatoire http://developpement.pragma-tech.online/societe/card.php?socid=15&save_lastsearch_values=1

	if (!GETPOST('lastname')) {
		setEventMessages($langs->trans('CLIENTPART_FORM_ERR_NAME'), null, 'errors');
		$error++;
	}

	if (!GETPOST('civility_code', 'alphanohtml')) {
		setEventMessages($langs->trans('CLIENTPART_FORM_ERR_CIVILITY'), null, 'errors');
		$error++;
	}

//	if (!GETPOST('civility_id')) {
//		setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv("ThirdPartyName")), null, 'errors');
//		$error++;
//	}



	if (!$error) {

		$backurlforlist = DOL_URL_ROOT . '/societe/list.php';

		if (empty($backtopage) || ($cancel && empty($id))) {
			if (empty($backtopage) || ($cancel && strpos($backtopage, '__ID__'))) {
				if (empty($id) && (($action != 'add' && $action != 'create') || $cancel)) {
					$backtopage = $backurlforlist;
				} else {

					$backtopage = DOL_URL_ROOT . '/societe/card.php?socid=' . $object->id . '&save_lastsearch_values=1';
				}
			}
		}
		// http://developpement.pragma-tech.online/societe/card.php?socid=15&save_lastsearch_values=1





		if ($action == 'update') {
			$ret = $object->fetch($socid);
			$object->oldcopy = clone $object;
		} else {
			$object->canvas = $canvas;
		}

		if ($action=='add') {

			$sql = "SELECT c.rowid,c.code,c.label ";
			$sql .= "FROM " . MAIN_DB_PREFIX . "c_civility as c ";
			$sql .= "WHERE c.code='" . GETPOST('civility_code', 'alphanohtml') . "'";

			$sqlRES = $db->query($sql);

			foreach ($sqlRES as $uneLigne) {
				$object->array_options[options_clientpart_civilite] = $uneLigne[rowid];
			}

			$object->name = dolGetFirstLastname(GETPOST('lastname', 'alphanohtml'), GETPOST('name', 'alphanohtml'));

			// Add non official properties
			$object->name_bis = GETPOST('lastname', 'alphanohtml');
			$object->array_options[options_clientpart_firstname] = GETPOST('firstname', 'alphanohtml');

			$object->name = GETPOST('lastname', 'alphanohtml');

			$object->entity = (GETPOSTISSET('entity') ? GETPOST('entity', 'int') : $conf->entity);
			$object->name_alias = GETPOST('name_alias', 'alphanohtml');
			$object->address = GETPOST('address', 'alphanohtml');
			$object->zip = GETPOST('zipcode', 'alphanohtml');
			$object->town = GETPOST('town', 'alphanohtml');
			$object->country_id = GETPOST('country_id', 'int');
			$object->state_id = GETPOST('state_id', 'int');
			$object->get_codeclient();

			$object->phone = GETPOST('phone_perso', 'alpha');
			//$object->fax = GETPOST('fax', 'alpha');
			$object->email = trim(GETPOST('email', 'custom', 0, FILTER_SANITIZE_EMAIL));


			$object->status = GETPOST('status', 'alpha');
			$object->typent_id = 8;
			$object->client = 1;
			$object->fournisseur = 0;
			$object->commercial_id = GETPOST('commercial_id', 'int');
			$object->default_lang = GETPOST('default_lang');
			$object->status = 1;


			$idNewObject=$object->create($user);


//			$backtopage = DOL_URL_ROOT . '/societe/card.php?socid=' . $idNewObject . '&save_lastsearch_values=1';
			$url = DOL_URL_ROOT."/societe/card.php?socid=".$idNewObject;
			setEventMessages($langs->trans('CLIENTPART_FORM_VALIDATE') . " " . $object->code_client . " - " . GETPOST('civility_code', 'alphanohtml') . " " . $object->name . " " . $object->array_options[options_clientpart_firstname], null);

			header("Location: ".$url);
			exit;


		}



		}

}


/*
 * View
 */

//DECLARATION OBJECT FORM
$form = new Form($db);
$formcompany = new FormCompany($db);
$formfile = new FormFile($db);

llxHeader("", $langs->trans("ClientPartArea"));

print load_fiche_titre(img_picto('', 'contact', 'class="paddingrightonly"').$langs->trans("ClientPartArea"), '', 'clientpart.png@clientpart');

print '<div class="tabBar tabBarWithBottom">';
print '<form enctype="multipart/form-data" action="'.$_SERVER["PHP_SELF"].'" method="post" name="formsoc" autocomplete="off">'; // Chrome ignor autocomplete

print '<input type="hidden" name="action" value="add">';
print '<input type="hidden" name="token" value="'.newToken().'">';

//print '<div class="fichecenter"><div class="fichethirdleft">';

print '<table class="border centpercent">';

// Ref/ID
if (!empty($conf->global->MAIN_SHOW_TECHNICAL_ID)) {
	print '<tr><td>'.$langs->trans("ID").'</td><td colspan="3">';
	print $object->ref;
	print '</td></tr>';
}

// Lastname
print '<tr><td class="titlefieldcreate fieldrequired"><label for="lastname">'.$langs->trans("Lastname").'</label></td>';
print '<td colspan="3"><input name="lastname" id="lastname" type="text" class="minwidth200" maxlength="80" value="'.(GETPOSTISSET("lastname") ? GETPOST("lastname") : $object->lastname).'" autofocus="autofocus"></td>';
print '</tr>';

// Firstname
print '<tr>';
print '<td class="titlefieldcreate fieldrequired"><label for="firstname">'.$langs->trans("Firstname").'</label></td>';
print '<td colspan="3"><input name="firstname" id="firstname" type="text" class="minwidth200" maxlength="80" value="'.(GETPOSTISSET("firstname") ? GETPOST("firstname") : $object->firstname).'"></td>';
print '</tr>';


// Civility
print '<tr><td class="titlefieldcreate fieldrequired"><label for="civility_code">'.$langs->trans("UserTitle").'</label></td><td colspan="3">';
print $formcompany->select_civility(GETPOSTISSET("civility_code") ? GETPOST("civility_code", "aZ09") : $object->civility_id, 'civility_code');

print '</td></tr>';


// Address
print '<tr><td><label for="address">'.$langs->trans("Address").'</label></td>';
print '<td colspan="3">';
print '<div class="paddingrightonly valignmiddle inline-block quatrevingtpercent">';
print '<textarea class="flat minwidth200 centpercent" name="address" id="address">'.(GETPOSTISSET("address") ? GETPOST("address", 'alphanohtml') : $object->address).'</textarea>';
print '</td>';

// Zip / Town
print '<tr><td><label for="zipcode">'.$langs->trans("Zip").'</label> / <label for="town">'.$langs->trans("Town").'</label></td><td colspan="3" class="maxwidthonsmartphone">';
print $formcompany->select_ziptown((GETPOSTISSET("zipcode") ? GETPOST("zipcode") : $object->zip), 'zipcode', array('town', 'selectcountry_id', 'state_id'), 6).'&nbsp;';
print $formcompany->select_ziptown((GETPOSTISSET("town") ? GETPOST("town") : $object->town), 'town', array('zipcode', 'selectcountry_id', 'state_id'));
print '</td></tr>';

// Country
print '<tr><td><label for="selectcountry_id">'.$langs->trans("Country").'</label></td><td colspan="3" class="maxwidthonsmartphone">';
print img_picto('', 'globe-americas', 'class="paddingrightonly"');
print $form->select_country(GETPOSTISSET("country_id") ? GETPOST("country_id") : $object->country_id, 'country_id');
if ($user->admin) {
	print info_admin($langs->trans("YouCanChangeValuesForThisListFromDictionarySetup"), 1);
}
print '</td></tr>';

// State
if (empty($conf->global->SOCIETE_DISABLE_STATE)) {
	if (!empty($conf->global->MAIN_SHOW_REGION_IN_STATE_SELECT) && ($conf->global->MAIN_SHOW_REGION_IN_STATE_SELECT == 1 || $conf->global->MAIN_SHOW_REGION_IN_STATE_SELECT == 2)) {
		print '<tr><td><label for="state_id">'.$langs->trans('CLIENTPART_FORM_LABEL_REGION-STATE').'</label></td><td colspan="3" class="maxwidthonsmartphone">';
	} else {
		print '<tr><td><label for="state_id">'.$langs->trans('CLIENTPART_FORM_LABEL_STATE').'</label></td><td colspan="3" class="maxwidthonsmartphone">';
	}

	print img_picto('', 'state', 'class="pictofixedwidth"');
	print $formcompany->select_state(GETPOSTISSET('state_id') ? GETPOST('state_id', 'alpha') : $object->state_id, $object->country_code, 'state_id');
	print '</td></tr>';
}

// Phone
/*print '<tr><td>'.$form->editfieldkey('PhonePro', 'phone_pro', GETPOST('phone_pro', 'alpha'), $object, 0).'</td>';
print '<td>';
print img_picto('', 'object_phoning');
print '<input type="text" name="phone_pro" id="phone_pro" class="maxwidth200" maxlength="80" value="'.(GETPOSTISSET('phone_pro') ?GETPOST('phone_pro', 'alpha') : $object->phone_pro).'"></td>';*/
print '<td>'.$form->editfieldkey('CLIENTPART_FORM_LABEL_TEL', 'phone', GETPOST('phone_perso', 'alpha'), $object, 0).'</td>';
print '<td>';
print img_picto('', 'object_phoning');
print '<input type="text" name="phone_perso" id="phone_perso" class="maxwidth200" maxlength="80" value="'.(GETPOSTISSET('phone_perso') ?GETPOST('phone_perso', 'alpha') : $object->phone_perso).'"></td></tr>';

/*print '<tr><td>'.$form->editfieldkey('PhoneMobile', 'phone_mobile', GETPOST('phone_mobile', 'alpha'), $object, 0, 'string', '').'</td>';
print '<td>';
print img_picto('', 'object_phoning_mobile');
print '<input type="text" name="phone_mobile" id="phone_mobile" class="maxwidth200" maxlength="80" value="'.(GETPOSTISSET('phone_mobile') ?GETPOST('phone_mobile', 'alpha') : $object->phone_mobile).'"></td>';*/
/*print '<td>'.$form->editfieldkey('Fax', 'fax', GETPOST('fax', 'alpha'), $object, 0).'</td>';
print '<td>';
print img_picto('', 'object_phoning_fax');
print '<input type="text" name="fax" id="fax" class="maxwidth200" maxlength="80" value="'.(GETPOSTISSET('phone_fax') ?GETPOST('phone_fax', 'alpha') : $object->fax).'"></td></tr>';*/

// EMail
print '<tr><td>'.$form->editfieldkey('CLIENTPART_FORM_LABEL_EMAIL', 'email', GETPOST('email', 'custom', 0, FILTER_SANITIZE_EMAIL), $object, 0, 'string', '', (!empty($conf->global->SOCIETE_EMAIL_MANDATORY))).'</td>';
print '<td colspan="3">'.img_picto('', 'object_email', 'class="pictofixedwidth"').' <input type="text" name="email" id="email" class="maxwidth200onsmartphone maxwidth500 widthcentpercentminusx" value="'.(GETPOSTISSET('email') ? GETPOST('email', 'custom', 0, FILTER_SANITIZE_EMAIL) : $object->email).'"></td></tr>';





print '</td>';
print '</tr>';

print '</table>';


print '</div>';
print '<br>';
print dol_get_fiche_end();
print $form->buttonsSaveCancel();

print '</form>';

/* BEGIN MODULEBUILDER DRAFT MYOBJECT
// Draft MyObject
if (! empty($conf->clientpart->enabled) && $user->rights->clientpart->read)
{
	$langs->load("orders");

	$sql = "SELECT c.rowid, c.ref, c.ref_client, c.total_ht, c.tva as total_tva, c.total_ttc, s.rowid as socid, s.nom as name, s.client, s.canvas";
	$sql.= ", s.code_client";
	$sql.= " FROM ".MAIN_DB_PREFIX."commande as c";
	$sql.= ", ".MAIN_DB_PREFIX."societe as s";
	if (! $user->rights->societe->client->voir && ! $socid) $sql.= ", ".MAIN_DB_PREFIX."societe_commerciaux as sc";
	$sql.= " WHERE c.fk_soc = s.rowid";
	$sql.= " AND c.fk_statut = 0";
	$sql.= " AND c.entity IN (".getEntity('commande').")";
	if (! $user->rights->societe->client->voir && ! $socid) $sql.= " AND s.rowid = sc.fk_soc AND sc.fk_user = ".((int) $user->id);
	if ($socid)	$sql.= " AND c.fk_soc = ".((int) $socid);

	$resql = $db->query($sql);
	if ($resql)
	{
		$total = 0;
		$num = $db->num_rows($resql);

		print '<table class="noborder centpercent">';
		print '<tr class="liste_titre">';
		print '<th colspan="3">'.$langs->trans("DraftMyObjects").($num?'<span class="badge marginleftonlyshort">'.$num.'</span>':'').'</th></tr>';

		$var = true;
		if ($num > 0)
		{
			$i = 0;
			while ($i < $num)
			{

				$obj = $db->fetch_object($resql);
				print '<tr class="oddeven"><td class="nowrap">';

				$myobjectstatic->id=$obj->rowid;
				$myobjectstatic->ref=$obj->ref;
				$myobjectstatic->ref_client=$obj->ref_client;
				$myobjectstatic->total_ht = $obj->total_ht;
				$myobjectstatic->total_tva = $obj->total_tva;
				$myobjectstatic->total_ttc = $obj->total_ttc;

				print $myobjectstatic->getNomUrl(1);
				print '</td>';
				print '<td class="nowrap">';
				print '</td>';
				print '<td class="right" class="nowrap">'.price($obj->total_ttc).'</td></tr>';
				$i++;
				$total += $obj->total_ttc;
			}
			if ($total>0)
			{

				print '<tr class="liste_total"><td>'.$langs->trans("Total").'</td><td colspan="2" class="right">'.price($total)."</td></tr>";
			}
		}
		else
		{

			print '<tr class="oddeven"><td colspan="3" class="opacitymedium">'.$langs->trans("NoOrder").'</td></tr>';
		}
		print "</table><br>";

		$db->free($resql);
	}
	else
	{
		dol_print_error($db);
	}
}
END MODULEBUILDER DRAFT MYOBJECT */





$NBMAX = $conf->global->MAIN_SIZE_SHORTLIST_LIMIT;
$max = $conf->global->MAIN_SIZE_SHORTLIST_LIMIT;

/* BEGIN MODULEBUILDER LASTMODIFIED MYOBJECT
// Last modified myobject
if (! empty($conf->clientpart->enabled) && $user->rights->clientpart->read)
{
	$sql = "SELECT s.rowid, s.ref, s.label, s.date_creation, s.tms";
	$sql.= " FROM ".MAIN_DB_PREFIX."clientpart_myobject as s";
	//if (! $user->rights->societe->client->voir && ! $socid) $sql.= ", ".MAIN_DB_PREFIX."societe_commerciaux as sc";
	$sql.= " WHERE s.entity IN (".getEntity($myobjectstatic->element).")";
	//if (! $user->rights->societe->client->voir && ! $socid) $sql.= " AND s.rowid = sc.fk_soc AND sc.fk_user = ".((int) $user->id);
	//if ($socid)	$sql.= " AND s.rowid = $socid";
	$sql .= " ORDER BY s.tms DESC";
	$sql .= $db->plimit($max, 0);

	$resql = $db->query($sql);
	if ($resql)
	{
		$num = $db->num_rows($resql);
		$i = 0;

		print '<table class="noborder centpercent">';
		print '<tr class="liste_titre">';
		print '<th colspan="2">';
		print $langs->trans("BoxTitleLatestModifiedMyObjects", $max);
		print '</th>';
		print '<th class="right">'.$langs->trans("DateModificationShort").'</th>';
		print '</tr>';
		if ($num)
		{
			while ($i < $num)
			{
				$objp = $db->fetch_object($resql);

				$myobjectstatic->id=$objp->rowid;
				$myobjectstatic->ref=$objp->ref;
				$myobjectstatic->label=$objp->label;
				$myobjectstatic->status = $objp->status;

				print '<tr class="oddeven">';
				print '<td class="nowrap">'.$myobjectstatic->getNomUrl(1).'</td>';
				print '<td class="right nowrap">';
				print "</td>";
				print '<td class="right nowrap">'.dol_print_date($db->jdate($objp->tms), 'day')."</td>";
				print '</tr>';
				$i++;
			}

			$db->free($resql);
		} else {
			print '<tr class="oddeven"><td colspan="3" class="opacitymedium">'.$langs->trans("None").'</td></tr>';
		}
		print "</table><br>";
	}
}
*/



// End of page
llxFooter();
$db->close();
